"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createHandler = void 0;
const node_1 = require("@graphql-yoga/node");
const resolvers_1 = require("./resolvers");
const path_1 = __importDefault(require("path"));
function getSchema() {
    return path_1.default.join(process.cwd(), 'schema', 'schema.docs-enterprise.graphql');
}
function createHandler({ users, githubRepositories, githubOrganizations, }) {
    let schema = getSchema();
    let resolvers = (0, resolvers_1.createResolvers)({
        users,
        githubRepositories,
        githubOrganizations,
    });
    let graphqlServer = (0, node_1.createServer)({
        schema: {
            typeDefs: schema,
            resolvers,
        },
        maskedErrors: false,
        logging: {
            // eslint-disable-next-line @typescript-eslint/no-unused-vars
            debug(..._args) { },
            warn(...args) {
                console.dir(...args);
            },
            // eslint-disable-next-line @typescript-eslint/no-unused-vars
            info(..._args) { },
            error(...args) {
                console.error(...args);
            },
        },
    });
    return graphqlServer;
}
exports.createHandler = createHandler;
//# sourceMappingURL=handler.js.map